/*
 * Task.java - implementation of tracked task
 *
 * Copyright (c) 2006 Lukas Jelinek, http://www.aiken.cz
 *
 * ==========================================================================
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * ==========================================================================
 */

package cz.aiken.util.lwtt;

import javax.swing.Timer;
import java.awt.event.*;

/**
 *
 * @author luk
 */
public class Task implements ActionListener, Comparable<Task> {
    private int id;
    
    private String name = "Unnamed task";
    private long consumption = 0L;
    
    private Timer timer = null;
    public static final int PERIOD = 10000;
    
    private ActionListener listener = null;
    
    private static int nextId = 0;
            
    public static int getNewId() {
        int id = nextId;
        nextId++;
        return id;
    }
    
    
    
    /** Creates a new instance of Task */
    public Task() {
        id = getNewId();
    }
    
    public Task(int id, String name, long consumption) {
        this.id = id;
        this.name = name;
        this.consumption = consumption;
        
        if (id >= nextId)
            nextId = id + 1;
    }
    
    public void setActionListener(ActionListener al) {
        listener = al;
    }
    
    public int getId() {
        return id;
    }
    
    public String getName() {
        return name;
    }
    
    public void setName(String name) {
        this.name = name;
    }
    
    public long getConsumption() {
        return consumption;
    }
    
    public void setConsumption(long consumption) {
        this.consumption = consumption;
    }
    
    public String toString() {
        return name + "(" + Long.toString(consumption) + ")";
    }
    
    public void start() {
        if (timer != null)
            return;
        
        timer = new Timer(PERIOD, this);
        timer.start();
    }
    
    public void stop() {
        if (timer == null)
            return;
        
        timer.stop();
        timer = null;
    }
    
    public boolean isRunning() {
        return timer != null;
    }
    
    public void actionPerformed(ActionEvent e) {
        consumption += PERIOD;
        
        ActionEvent e2 = new ActionEvent(this, id, "");
        
        if (listener != null)
            listener.actionPerformed(e2);
    }

    public int compareTo(Task t) {
        if (t == null)
            throw new NullPointerException("cannot compare to null pointer");
        
        if (id > t.getId())
           return 1;
        else if (id == t.getId())
            return 0;
        else
            return -1;
    }    
    
}
