/*
 * TaskFrame.java - implementation of LWTT main application window
 *
 * Copyright (c) 2006 Lukas Jelinek, http://www.aiken.cz
 *
 * ==========================================================================
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * ==========================================================================
 */

package cz.aiken.util.lwtt;

import java.awt.*;
import javax.swing.*;
import javax.swing.table.*;
import javax.swing.event.*;

/**
 *
 * @author  luk
 */
public class TaskFrame extends javax.swing.JFrame implements ListSelectionListener {
    
    private TaskTableModel model = new TaskTableModel();
    
    /** Creates new form TaskFrame */
    public TaskFrame() {
        initComponents();
        jTable1.getSelectionModel().addListSelectionListener(this);
        updateButtons();
    }
    
    void updateButtons() {
        int cnt = jTable1.getSelectedRowCount();
        if (cnt == 0) {
            startButton.setEnabled(false);
            stopButton.setEnabled(false);
            removeButton.setEnabled(false);
        }
        else {
            int start = jTable1.getSelectedRow();
            int end = start + cnt - 1;
            removeButton.setEnabled(true);
            
            for (int i=start; i<=end; i++) {
                if (model.isRunning(i)) {
                    startButton.setEnabled(false);
                    stopButton.setEnabled(true);
                }
                else {
                    startButton.setEnabled(true);
                    stopButton.setEnabled(false);
                }
            }
        }
    }
    
    public void valueChanged(ListSelectionEvent e) {
        updateButtons();
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        jSplitPane1 = new javax.swing.JSplitPane();
        jPanel1 = new javax.swing.JPanel();
        startButton = new javax.swing.JButton();
        stopButton = new javax.swing.JButton();
        addButton = new javax.swing.JButton();
        removeButton = new javax.swing.JButton();
        jScrollPane1 = new javax.swing.JScrollPane();
        jTable1 = new javax.swing.JTable();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("LWTT");
        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                TaskFrame.this.windowClosing(evt);
            }
        });

        jSplitPane1.setOrientation(javax.swing.JSplitPane.VERTICAL_SPLIT);
        jPanel1.setMinimumSize(new java.awt.Dimension(10, 25));
        startButton.setText("Start");
        startButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                startPressed(evt);
            }
        });

        stopButton.setText("Stop");
        stopButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                stopPressed(evt);
            }
        });

        addButton.setText("Add");
        addButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                addPressed(evt);
            }
        });

        removeButton.setText("Remove");
        removeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                removePressed(evt);
            }
        });

        org.jdesktop.layout.GroupLayout jPanel1Layout = new org.jdesktop.layout.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .add(startButton)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(stopButton)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(addButton)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(removeButton)
                .addContainerGap(310, Short.MAX_VALUE))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.BASELINE, startButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 25, Short.MAX_VALUE)
            .add(org.jdesktop.layout.GroupLayout.BASELINE, stopButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 25, Short.MAX_VALUE)
            .add(org.jdesktop.layout.GroupLayout.BASELINE, addButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 25, Short.MAX_VALUE)
            .add(org.jdesktop.layout.GroupLayout.BASELINE, removeButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 25, Short.MAX_VALUE)
        );
        jSplitPane1.setTopComponent(jPanel1);

        jScrollPane1.setPreferredSize(new java.awt.Dimension(454, 400));
        jScrollPane1.setVerifyInputWhenFocusTarget(false);
        jScrollPane1.setViewport(null);
        jTable1.setModel(model);
        jTable1.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_INTERVAL_SELECTION);
        jTable1.setDefaultRenderer(Long.class, new DefaultTableCellRenderer() {
            private Color fg = Color.RED;
            private Color bg = new Color(255, 240, 240);

            public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
                Component c = super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
                if (JLabel.class.isAssignableFrom(c.getClass())) {
                    ((JLabel) c).setHorizontalAlignment(JLabel.TRAILING);
                }

                if (model.isRunning(row)) {
                    c.setForeground(fg);
                    if (!isSelected)
                    c.setBackground(bg);
                }
                else {
                    c.setForeground(Color.BLACK);
                    if (!isSelected)
                    c.setBackground(Color.WHITE);
                }

                return c;
            }
        });
        jScrollPane1.setViewportView(jTable1);

        jSplitPane1.setRightComponent(jScrollPane1);

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(org.jdesktop.layout.GroupLayout.TRAILING, jSplitPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 572, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jSplitPane1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 441, Short.MAX_VALUE)
        );
        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void windowClosing(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_windowClosing
        model.stopAllTasks();
        model.saveToFile();
    }//GEN-LAST:event_windowClosing

    private void removePressed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_removePressed
        int start = jTable1.getSelectedRow();
        int cnt = jTable1.getSelectedRowCount();
        if (cnt > 0)
            model.removeTasks(start, start + cnt - 1);
            
    }//GEN-LAST:event_removePressed

    private void addPressed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_addPressed
        model.addNewTask();
    }//GEN-LAST:event_addPressed

    private void stopPressed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_stopPressed
        int start = jTable1.getSelectedRow();
        int cnt = jTable1.getSelectedRowCount();
        if (cnt > 0) {
            model.stopTasks(start, start + cnt - 1);
            updateButtons();
        }
    }//GEN-LAST:event_stopPressed

    private void startPressed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_startPressed
        int start = jTable1.getSelectedRow();
        int cnt = jTable1.getSelectedRowCount();
        if (cnt > 0) {
            model.startTasks(start, start + cnt - 1);
            updateButtons();
        }
    }//GEN-LAST:event_startPressed
          
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton addButton;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JSplitPane jSplitPane1;
    private javax.swing.JTable jTable1;
    private javax.swing.JButton removeButton;
    private javax.swing.JButton startButton;
    private javax.swing.JButton stopButton;
    // End of variables declaration//GEN-END:variables
    
}
